@@ -1,4 +1,4 @@
-## Copyright 2012 Sebastian Gibb
+## Copyright 2012-2014 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquantForeign for R and related languages.
@@ -19,7 +19,8 @@
 #' Import files
 #'
 #' This function provides a general interface to import different file formats
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @details
 #' Specific import functions:
@@ -33,6 +34,7 @@
 #'  mzML \tab \code{\link[MALDIquantForeign]{importMzMl}} \cr
 #'  imzML \tab \code{\link[MALDIquantForeign]{importImzMl}} \cr
 #'  analyze \tab \code{\link[MALDIquantForeign]{importAnalyze}} \cr
+#'  cdf \tab \code{\link[MALDIquantForeign]{importCdf}} \cr
 #' }
 #'
 #' \code{path}: In addition to the above mentioned file types the
@@ -47,6 +49,11 @@
 #' extension (e.g. \code{pattern="^.*\\.xml$"} to read all \code{*.xml}
 #' files in a directory; see \code{\link[base]{regexp}} for details).
 #'
+#' \code{excludePattern}: Sometimes some files should be excluded. E.g.
+#' to ignore additional aquired Bruker LIFT spectra
+#' (MALDI-TOF/TOF; which are not support, yet) you could use
+#' \code{excludePattern="([[:digit:]\\.]+)LIFT[\\\\/]1SRef"}.
+#'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param type \code{character}, file format. If \code{type} is set to
@@ -56,14 +63,25 @@
 #'  \code{pattern} argument is ignored).
 #' @param pattern \code{character}, a regular expression to find files in a
 #'  directory (see details).
+#' @param excludePattern \code{character}, a regular expression to exclude
+#'  files in a directory (see details).
 #' @param removeEmptySpectra \code{logical}, should empty spectra excluded?
+#' @param centroided \code{logical}, if \code{centroided=TRUE} a list of
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects is returned otherwise
+#' a list of \code{\link[MALDIquant]{MassSpectrum-class}} objects. If
+#' \code{centroided=NA} \code{import} tries to guess the correct value.
+#' @param massRange \code{double}, limits of mass import (left/minimal mass,
+#' right/maximal mass).
+#' @param minIntensity \code{double}, minimal intensity to import.
 #' @param verbose \code{logical}, verbose output?
 #' @param \ldots arguments to be passed to specific import functions.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
-#' \code{\link[MALDIquant]{MassSpectrum-class}}
+#' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}
 #' @examples
@@ -89,7 +107,9 @@
 #'
 #' @rdname import-functions
 #' @export
-import <- function(path, type="auto", pattern, removeEmptySpectra=TRUE, verbose=TRUE, ...) {
+import <- function(path, type="auto", pattern, excludePattern=NULL,
+                   removeEmptySpectra=TRUE, centroided=NA, massRange=c(0, Inf),
+                   minIntensity=0, verbose=TRUE, ...) {
 
   ## download file if needed
   isUrl <- .isUrl(path)
@@ -125,16 +145,20 @@ import <- function(path, type="auto", pattern, removeEmptySpectra=TRUE, verbose=
     if (!missing(pattern)) {
       warning("User defined ", sQuote("pattern"), " is ignored in auto-mode.")
     }
-    return(.importAuto(path=path, removeEmptySpectra=removeEmptySpectra,
-                       verbose=verbose, ...))
+    return(.importAuto(path=path, excludePattern=excludePattern,
+                       removeEmptySpectra=removeEmptySpectra,
+                       centroided=centroided, massRange=massRange,
+                       minIntensity=minIntensity, verbose=verbose, ...))
   } else {
     ## user-defined file type
     if (missing(pattern)) {
       pattern <- importFormats$pattern[i]
     }
     handler <- importFormats$handler[i]
-    s <- unlist(lapply(.files(path=path, pattern=pattern), handler,
-                       verbose=verbose, ...))
+    s <- unlist(lapply(.files(path=path, pattern=pattern,
+                              excludePattern=excludePattern),
+                       handler, centroided=centroided, massRange=massRange,
+                       minIntensity=minIntensity, verbose=verbose, ...))
     if (is.null(s)) {
       stop("Import failed! Unsupported file type?")
     }
@@ -157,7 +181,8 @@ import <- function(path, type="auto", pattern, removeEmptySpectra=TRUE, verbose=
 #' Import text files
 #'
 #' This function imports different text file formats
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' \code{importTab}, \code{importTxt} and \code{importCsv} use
 #' \code{\link[utils]{read.table}} with different defaults.
@@ -166,10 +191,12 @@ import <- function(path, type="auto", pattern, removeEmptySpectra=TRUE, verbose=
 #'  in.
 #' @param \ldots arguments to be passed to \code{\link[utils]{read.table}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
 #' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}},
 #' \code{\link[utils]{read.table}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}
@@ -209,17 +236,20 @@ importCsv <- function(path, ...) {
 #' Import Bruker Daltonics *flex files
 #'
 #' This function imports files in Bruker Daltonics *flex-series file format
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param \ldots arguments to be passed to
 #' \code{\link[readBrukerFlexData]{readBrukerFlexFile}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
 #' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}},
 #' \code{\link[readBrukerFlexData]{readBrukerFlexFile}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}
@@ -243,17 +273,20 @@ importBrukerFlex <- function(path, ...) {
 #' Import mzXML files
 #'
 #' This function imports files in mzXML file format
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param \ldots arguments to be passed to
 #' \code{\link[readMzXmlData]{readMzXmlFile}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
 #' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}},
 #' \code{\link[readMzXmlData]{readMzXmlFile}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}, \cr
@@ -280,17 +313,20 @@ importMzXml <- function(path, ...) {
 #' Import mzML files
 #'
 #' This function imports files in mzML file format
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param \ldots arguments to be passed to
 #' \code{\link[MALDIquantForeign]{import}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
-#' \code{\link[MALDIquant]{MassSpectrum-class}}
+#' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}, \cr
 #' Definition of \code{mzML} format:
@@ -316,17 +352,20 @@ importMzMl <- function(path, ...) {
 #' Import imzML files
 #'
 #' This function imports files in imzML file format
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param \ldots arguments to be passed to
 #' \code{\link[MALDIquantForeign]{import}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
-#' \code{\link[MALDIquant]{MassSpectrum-class}}
+#' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}, \cr
 #' Definition of \code{imzML} format:
@@ -352,17 +391,20 @@ importImzMl <- function(path, ...) {
 #' Import Ciphergen XML files
 #'
 #' This function imports files in Ciphergen XML file format
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param \ldots arguments to be passed to
 #' \code{\link[MALDIquantForeign]{import}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
-#' \code{\link[MALDIquant]{MassSpectrum-class}}
+#' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/}
 #' @examples
@@ -386,17 +428,20 @@ importCiphergenXml <- function(path, ...) {
 #' Import Analyze 7.5 files
 #'
 #' This function imports files in Analyze 7.5 file format
-#' into \code{\link[MALDIquant]{MassSpectrum-class}} objects.
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.
 #'
 #' @param path \code{character}, path to directory or file which should be read
 #'  in.
 #' @param \ldots arguments to be passed to
 #' \code{\link[MALDIquantForeign]{import}}.
 #'
-#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}}
-#'  objects.
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
 #' @seealso
-#' \code{\link[MALDIquant]{MassSpectrum-class}}
+#' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}}
 #' @author Sebastian Gibb
 #' @references \url{http://strimmerlab.org/software/maldiquant/} \cr
 #'  \url{http://www.grahamwideman.com/gw/brain/analyze/formatdoc.htm},
@@ -407,3 +452,41 @@ importAnalyze <- function(path, ...) {
   return(import(path=path, type="analyze", ...))
 }
 
+#' Import CDF files
+#'
+#' This function imports files in NetCDF file format
+#' into \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects.\cr
+#' Please note that the \emph{RNetCDF} is needed.
+#'
+#' @param path \code{character}, path to directory or file which should be read
+#'  in.
+#' @param \ldots arguments to be passed to
+#' \code{\link[MALDIquantForeign]{import}}.
+#'
+#' @return a \code{list} of \code{\link[MALDIquant]{MassSpectrum-class}} or
+#' \code{\link[MALDIquant]{MassPeaks-class}} objects (depending on the
+#' \code{centroided} argument).
+#' @seealso
+#' \code{\link[MALDIquant]{MassSpectrum-class}},
+#' \code{\link[MALDIquant]{MassPeaks-class}}
+#' @author Sebastian Gibb
+#' @references \url{http://strimmerlab.org/software/maldiquant/}
+#' @examples
+#'
+#' library("MALDIquant")
+#' library("MALDIquantForeign")
+#'
+#' ## get example directory
+#' exampleDirectory <- system.file(file.path("tests", "data"),
+#'                                 package="MALDIquantForeign")
+#'
+#' ## import
+#' s <- importCdf(exampleDirectory)
+#'
+#' @rdname importCdf-functions
+#' @export
+importCdf <- function(path, ...) {
+  return(import(path=path, type="cdf", ...))
+}
+
