@@ -1,2 +1,2 @@
-library(testthat)
+library("testthat")
 test_package("MALDIquantForeign")
